Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1231)

Unified Diff: Source/core/streams/ReadableStream.h

Issue 1001233002: Streams Implementation Update: Reader name and Stream methods (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/streams/ExclusiveStreamReaderTest.cpp ('k') | Source/core/streams/ReadableStream.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/streams/ReadableStream.h
diff --git a/Source/core/streams/ReadableStream.h b/Source/core/streams/ReadableStream.h
index b322c080d356d1d035cfb44249f36e9b3292aa94..1dea3cce09cc0c0ebbca965571755e7a8b5bf6a8 100644
--- a/Source/core/streams/ReadableStream.h
+++ b/Source/core/streams/ReadableStream.h
@@ -21,7 +21,7 @@ namespace blink {
class DOMException;
class ExceptionState;
-class ExclusiveStreamReader;
+class ReadableStreamReader;
class UnderlyingSource;
class ReadableStream : public GarbageCollectedFinalized<ReadableStream>, public ScriptWrappable, public ActiveDOMObject {
@@ -64,14 +64,14 @@ public:
void didSourceStart();
// This function is not a getter. It creates an ExclusiveStreamReader and
// returns it.
- ExclusiveStreamReader* getReader(ExceptionState&);
- // Only ExclusiveStreamReader methods should call this function.
- void setReader(ExclusiveStreamReader*);
+ ReadableStreamReader* getReader(ExceptionState&);
+ // Only ReadableStreamReader methods should call this function.
+ void setReader(ReadableStreamReader*);
bool isLocked() const { return m_reader; }
- bool isLockedTo(const ExclusiveStreamReader* reader) const { return m_reader == reader; }
+ bool isLockedTo(const ReadableStreamReader* reader) const { return m_reader == reader; }
bool hasPendingActivity() const override;
void stop() override;
@@ -107,7 +107,7 @@ private:
Member<ClosedPromise> m_closed;
RefPtrWillBeMember<DOMException> m_exception;
- Member<ExclusiveStreamReader> m_reader;
+ Member<ReadableStreamReader> m_reader;
};
} // namespace blink
« no previous file with comments | « Source/core/streams/ExclusiveStreamReaderTest.cpp ('k') | Source/core/streams/ReadableStream.cpp » ('j') | no next file with comments »
@@ -64,14 +64,14 @@ public:
void didSourceStart();
- // This function is not a getter. It creates an ExclusiveStreamReader and
+ // This function is not a getter. It creates an ReadableStreamReader and
// returns it.

Powered by Google App Engine
This is Rietveld 408576698